| Title: | Provide 'tldrPages' Documentation for Base R Functions |
|---|---|
| Description: | Documentation for commonly-used objects included in the base distribution of R. Note that 'tldrDocs' does not export any functions itself, its purpose is to write .Rd files during its installation for 'tldr()' to find. |
| Authors: | James Otto [aut, cre] (ORCID: <https://orcid.org/0000-0002-0665-2515>), David Kahle [aut] (ORCID: <https://orcid.org/0000-0002-9999-1558>) |
| Maintainer: | James Otto <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-06-02 07:08:29 UTC |
| Source: | https://github.com/jamesotto852/tldrdocs |
A collection of tldr-style documentation for commonly-used objects exported in the base distribution of R.
Maintainer: James Otto [email protected] (ORCID)
Authors:
David Kahle [email protected] (ORCID)
Useful links: