Welcome to ClientVPS Mirrors

Help for package tldrDocs
Title: Provide 'tldrPages' Documentation for Base R Functions
Version: 0.0.1
Description: Documentation for commonly-used objects included in the base distribution of R. Note that 'tldrDocs' does not export any functions itself, its purpose is to write .Rd files during its installation for 'tldr()' to find.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-10-30 18:45:22 UTC; rstudio
Author: James Otto ORCID iD [aut, cre], David Kahle ORCID iD [aut]
Maintainer: James Otto <jamesotto852@gmail.com>
Repository: CRAN
Date/Publication: 2025-11-03 19:30:02 UTC

tldrDocs: tldr-style documentation for base R packages

Description

A collection of tldr-style documentation for commonly-used objects exported in the base distribution of R.

Author(s)

Maintainer: James Otto jamesotto852@gmail.com (ORCID)

Authors:

See Also

Useful links:

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.